==> TencentNavKitDocument_7.2.1.zip: TencentNavKitDocument/menudata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var menudata={children:[
{text:"Main Page",url:"index.html"},
{text:"Classes",url:"annotated.html",children:[
{text:"Class List",url:"annotated.html"},
{text:"Class Index",url:"classes.html"},
{text:"Class Hierarchy",url:"hierarchy.html"},
{text:"Class Members",url:"functions.html",children:[
{text:"All",url:"functions.html",children:[
{text:"a",url:"functions.html#index_a"},
{text:"b",url:"functions_b.html#index_b"},
{text:"c",url:"functions_c.html#index_c"},
{text:"d",url:"functions_d.html#index_d"},
{text:"e",url:"functions_e.html#index_e"},
{text:"f",url:"functions_f.html#index_f"},
{text:"g",url:"functions_g.html#index_g"},
{text:"h",url:"functions_h.html#index_h"},
{text:"i",url:"functions_i.html#index_i"},
{text:"j",url:"functions_j.html#index_j"},
{text:"k",url:"functions_k.html#index_k"},
{text:"l",url:"functions_l.html#index_l"},
{text:"m",url:"functions_m.html#index_m"},
{text:"n",url:"functions_n.html#index_n"},
{text:"o",url:"functions_o.html#index_o"},
{text:"p",url:"functions_p.html#index_p"},
{text:"r",url:"functions_r.html#index_r"},
{text:"s",url:"functions_s.html#index_s"},
{text:"t",url:"functions_t.html#index_t"},
{text:"u",url:"functions_u.html#index_u"},
{text:"v",url:"functions_v.html#index_v"},
{text:"w",url:"functions_w.html#index_w"}]},
{text:"Functions",url:"functions_func.html",children:[
{text:"a",url:"functions_func.html#index_a"},
{text:"b",url:"functions_func_b.html#index_b"},
{text:"c",url:"functions_func_c.html#index_c"},
{text:"d",url:"functions_func_d.html#index_d"},
{text:"g",url:"functions_func_g.html#index_g"},
{text:"i",url:"functions_func_i.html#index_i"},
{text:"m",url:"functions_func_m.html#index_m"},
{text:"n",url:"functions_func_n.html#index_n"},
{text:"p",url:"functions_func_p.html#index_p"},
{text:"r",url:"functions_func_r.html#index_r"},
{text:"s",url:"functions_func_s.html#index_s"},
{text:"t",url:"functions_func_t.html#index_t"},
{text:"u",url:"functions_func_u.html#index_u"},
{text:"w",url:"functions_func_w.html#index_w"}]},
{text:"Properties",url:"functions_prop.html",children:[
{text:"a",url:"functions_prop.html#index_a"},
{text:"b",url:"functions_prop_b.html#index_b"},
{text:"c",url:"functions_prop_c.html#index_c"},
{text:"d",url:"functions_prop_d.html#index_d"},
{text:"e",url:"functions_prop_e.html#index_e"},
{text:"f",url:"functions_prop_f.html#index_f"},
{text:"g",url:"functions_prop_g.html#index_g"},
{text:"h",url:"functions_prop_h.html#index_h"},
{text:"i",url:"functions_prop_i.html#index_i"},
{text:"j",url:"functions_prop_j.html#index_j"},
{text:"k",url:"functions_prop_k.html#index_k"},
{text:"l",url:"functions_prop_l.html#index_l"},
{text:"m",url:"functions_prop_m.html#index_m"},
{text:"n",url:"functions_prop_n.html#index_n"},
{text:"o",url:"functions_prop_o.html#index_o"},
{text:"p",url:"functions_prop_p.html#index_p"},
{text:"r",url:"functions_prop_r.html#index_r"},
{text:"s",url:"functions_prop_s.html#index_s"},
{text:"t",url:"functions_prop_t.html#index_t"},
{text:"u",url:"functions_prop_u.html#index_u"},
{text:"v",url:"functions_prop_v.html#index_v"},
{text:"w",url:"functions_prop_w.html#index_w"}]}]}]},
{text:"Files",url:"files.html",children:[
{text:"File List",url:"files.html"},
{text:"File Members",url:"globals.html",children:[
{text:"All",url:"globals.html",children:[
{text:"_",url:"globals.html#index__5F"},
{text:"k",url:"globals_k.html#index_k"},
{text:"n",url:"globals_n.html#index_n"},
{text:"t",url:"globals_t.html#index_t"}]},
{text:"Functions",url:"globals_func.html"},
{text:"Variables",url:"globals_vars.html"},
{text:"Typedefs",url:"globals_type.html",children:[
{text:"_",url:"globals_type.html#index__5F"},
{text:"t",url:"globals_type.html#index_t"}]},
{text:"Enumerations",url:"globals_enum.html",children:[
{text:"_",url:"globals_enum.html#index__5F"},
{text:"t",url:"globals_enum.html#index_t"}]},
{text:"Enumerator",url:"globals_eval.html",children:[
{text:"t",url:"globals_eval.html#index_t"}]}]}]}]}

==> TencentNavKitDocument_7.3.3.zip: TencentNavKitDocument/menudata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var menudata={children:[
{text:"Main Page",url:"index.html"},
{text:"Classes",url:"annotated.html",children:[
{text:"Class List",url:"annotated.html"},
{text:"Class Index",url:"classes.html"},
{text:"Class Hierarchy",url:"hierarchy.html"},
{text:"Class Members",url:"functions.html",children:[
{text:"All",url:"functions.html",children:[
{text:"a",url:"functions.html#index_a"},
{text:"b",url:"functions_b.html#index_b"},
{text:"c",url:"functions_c.html#index_c"},
{text:"d",url:"functions_d.html#index_d"},
{text:"e",url:"functions_e.html#index_e"},
{text:"f",url:"functions_f.html#index_f"},
{text:"g",url:"functions_g.html#index_g"},
{text:"h",url:"functions_h.html#index_h"},
{text:"i",url:"functions_i.html#index_i"},
{text:"j",url:"functions_j.html#index_j"},
{text:"k",url:"functions_k.html#index_k"},
{text:"l",url:"functions_l.html#index_l"},
{text:"m",url:"functions_m.html#index_m"},
{text:"n",url:"functions_n.html#index_n"},
{text:"o",url:"functions_o.html#index_o"},
{text:"p",url:"functions_p.html#index_p"},
{text:"r",url:"functions_r.html#index_r"},
{text:"s",url:"functions_s.html#index_s"},
{text:"t",url:"functions_t.html#index_t"},
{text:"u",url:"functions_u.html#index_u"},
{text:"v",url:"functions_v.html#index_v"},
{text:"w",url:"functions_w.html#index_w"}]},
{text:"Functions",url:"functions_func.html",children:[
{text:"a",url:"functions_func.html#index_a"},
{text:"b",url:"functions_func_b.html#index_b"},
{text:"c",url:"functions_func_c.html#index_c"},
{text:"d",url:"functions_func_d.html#index_d"},
{text:"g",url:"functions_func_g.html#index_g"},
{text:"i",url:"functions_func_i.html#index_i"},
{text:"m",url:"functions_func_m.html#index_m"},
{text:"n",url:"functions_func_n.html#index_n"},
{text:"p",url:"functions_func_p.html#index_p"},
{text:"r",url:"functions_func_r.html#index_r"},
{text:"s",url:"functions_func_s.html#index_s"},
{text:"t",url:"functions_func_t.html#index_t"},
{text:"u",url:"functions_func_u.html#index_u"},
{text:"w",url:"functions_func_w.html#index_w"}]},
{text:"Properties",url:"functions_prop.html",children:[
{text:"a",url:"functions_prop.html#index_a"},
{text:"b",url:"functions_prop_b.html#index_b"},
{text:"c",url:"functions_prop_c.html#index_c"},
{text:"d",url:"functions_prop_d.html#index_d"},
{text:"e",url:"functions_prop_e.html#index_e"},
{text:"f",url:"functions_prop_f.html#index_f"},
{text:"g",url:"functions_prop_g.html#index_g"},
{text:"h",url:"functions_prop_h.html#index_h"},
{text:"i",url:"functions_prop_i.html#index_i"},
{text:"j",url:"functions_prop_j.html#index_j"},
{text:"k",url:"functions_prop_k.html#index_k"},
{text:"l",url:"functions_prop_l.html#index_l"},
{text:"m",url:"functions_prop_m.html#index_m"},
{text:"n",url:"functions_prop_n.html#index_n"},
{text:"o",url:"functions_prop_o.html#index_o"},
{text:"p",url:"functions_prop_p.html#index_p"},
{text:"r",url:"functions_prop_r.html#index_r"},
{text:"s",url:"functions_prop_s.html#index_s"},
{text:"t",url:"functions_prop_t.html#index_t"},
{text:"u",url:"functions_prop_u.html#index_u"},
{text:"v",url:"functions_prop_v.html#index_v"},
{text:"w",url:"functions_prop_w.html#index_w"}]}]}]},
{text:"Files",url:"files.html",children:[
{text:"File List",url:"files.html"},
{text:"File Members",url:"globals.html",children:[
{text:"All",url:"globals.html",children:[
{text:"_",url:"globals.html#index__5F"},
{text:"g",url:"globals_g.html#index_g"},
{text:"k",url:"globals_k.html#index_k"},
{text:"l",url:"globals_l.html#index_l"},
{text:"n",url:"globals_n.html#index_n"},
{text:"t",url:"globals_t.html#index_t"}]},
{text:"Functions",url:"globals_func.html"},
{text:"Variables",url:"globals_vars.html"},
{text:"Typedefs",url:"globals_type.html",children:[
{text:"_",url:"globals_type.html#index__5F"},
{text:"t",url:"globals_type.html#index_t"}]},
{text:"Enumerations",url:"globals_enum.html",children:[
{text:"_",url:"globals_enum.html#index__5F"},
{text:"t",url:"globals_enum.html#index_t"}]},
{text:"Enumerator",url:"globals_eval.html",children:[
{text:"g",url:"globals_eval.html#index_g"},
{text:"l",url:"globals_eval_l.html#index_l"},
{text:"n",url:"globals_eval_n.html#index_n"},
{text:"t",url:"globals_eval_t.html#index_t"}]}]}]}]}
